@@ -133,7 +133,7 @@ void MainWindow::setup()
     ui->tabWidget->setTabEnabled(ui->tabWidget->indexOf(ui->tabOutput), false);
     ui->tabWidget->blockSignals(false);
 
-    QSettings settings("MX-Linux", "mx-packageinstaller");
+    QSettings settings("mx-packageinstaller");
     restoreGeometry(settings.value("geometry").toByteArray());
 }
 
@@ -211,8 +211,8 @@ void MainWindow::listSizeInstalledFP()
     QString total = "0 bytes";
     QStringList list, runtimes;
     if (fp_ver < VersionNumber("1.0.1")) { // older version doesn't display all apps and runtimes without specifying them
-        list = cmd->getOutput("su $(logname) -c \"flatpak -d list --app " + user + "|tr -s ' ' |cut -f1,5,6 -d' '\"").split("\n");
-        runtimes = cmd->getOutput("su $(logname) -c \"flatpak -d list --runtime " + user + "|tr -s ' '|cut -f1,5,6 -d' '\"").split("\n");
+        list = cmd->getOutput("su -l $(logname) -c \"flatpak -d list --app " + user + "|tr -s ' ' |cut -f1,5,6 -d' '\"").split("\n");
+        runtimes = cmd->getOutput("su -l $(logname) -c \"flatpak -d list --runtime " + user + "|tr -s ' '|cut -f1,5,6 -d' '\"").split("\n");
         if (!runtimes.isEmpty()) {
             list << runtimes;
         }
@@ -228,9 +228,9 @@ void MainWindow::listSizeInstalledFP()
             ++it;
         }
     } else if (fp_ver < VersionNumber("1.2.4")) {
-        list = cmd->getOutput("su $(logname) -c \"flatpak -d list " + user + "|tr -s ' '|cut -f1,5\"").split("\n");
+        list = cmd->getOutput("su -l $(logname) -c \"flatpak -d list " + user + "|tr -s ' '|cut -f1,5\"").split("\n");
     } else {
-        list = cmd->getOutput("su $(logname) -c \"flatpak -d list " + user + "|tr -s ' '|cut -f2,11\"").split("\n");
+        list = cmd->getOutput("su -l $(logname) -c \"flatpak -d list " + user + "|tr -s ' '|cut -f2,11\"").split("\n");
     }
     for (const QString &item : list) {
         total = addSizes(total, item.section("\t", 1));
@@ -927,7 +927,7 @@ void MainWindow::listFlatpakRemotes()
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
     ui->comboRemote->blockSignals(true);
     ui->comboRemote->clear();
-    QStringList list = cmd->getOutput("su $(logname) -c \"flatpak remote-list " +  user + "| cut -f1\"").remove(" ").split("\n");
+    QStringList list = cmd->getOutput("su -l $(logname) -c \"flatpak remote-list " +  user + "| cut -f1\"").remove(" ").split("\n");
     ui->comboRemote->addItems(list);
     //set flathub default
     ui->comboRemote->setCurrentIndex(ui->comboRemote->findText("flathub"));
@@ -1408,7 +1408,7 @@ void MainWindow::cleanup()
         system("rm -r " + tmp_dir.toUtf8());
     }
 
-    QSettings settings("MX-Linux", "mx-packageinstaller");
+    QSettings settings("mx-packageinstaller");
     settings.setValue("geometry", saveGeometry());
 }
 
@@ -1491,25 +1491,25 @@ QStringList MainWindow::listFlatpaks(const QString remote, const QString type)
     if (fp_ver < VersionNumber("1.0.1")) {
         arch_fp = (arch == "amd64") ? arch_fp = "--arch=x86_64 " : arch_fp = "--arch=i386 ";
         // list packages, strip first part remote/ or app/ no size for old flatpak
-        list = cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + type + "| cut -f1 | tr -s ' ' | cut -f1 -d' '|sed 's/^[^\\/]*\\///g' \"").split("\n");
+        list = cmd->getOutput("su -l $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + type + "| cut -f1 | tr -s ' ' | cut -f1 -d' '|sed 's/^[^\\/]*\\///g' \"").split("\n");
     } else if (fp_ver < VersionNumber("1.2.4")) { // lower than Buster version
         // list size too
-        list = cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + type + "| cut -f1,3 |tr -s ' ' | sed 's/^[^\\/]*\\///g' \"").split("\n");
+        list = cmd->getOutput("su -l $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + type + "| cut -f1,3 |tr -s ' ' | sed 's/^[^\\/]*\\///g' \"").split("\n");
     } else { // Buster version and above
         if (!updated) {
-            cmd->run("su $(logname) -c \"flatpak update --appstream\"");
+            cmd->run("su -l $(logname) -c \"flatpak update --appstream\"");
             updated = true;
         }
         // list version too
         QString process_string; // unfortunatelly the resulting string structure is different depending on type option
         if (type == "--app" || type.isEmpty()) {
             process_string = "| cut -f3,6,9";
-            list = cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + "--app" + process_string + " \"").split("\n");
+            list = cmd->getOutput("su -l $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + "--app" + process_string + " \"").split("\n");
             if (list == QStringList("")) list = QStringList();
         }
         if (type == "--runtime" || type.isEmpty()) {
             process_string = "| cut -f4,6,9";
-            list += cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + "--runtime" + process_string + " \"").split("\n");
+            list += cmd->getOutput("su -l $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + "--runtime" + process_string + " \"").split("\n");
         }
     }
 
@@ -1526,9 +1526,9 @@ QStringList MainWindow::listInstalledFlatpaks(const QString type) const
 {
     QStringList list;
     if (fp_ver < VersionNumber("1.2.4")) {
-        list << cmd->getOutput("su $(logname) -c \"flatpak -d list " + user + type + "|cut -f1|cut -f1 -d' '\"").remove(" ").split("\n");
+        list << cmd->getOutput("su -l $(logname) -c \"flatpak -d list " + user + type + "|cut -f1|cut -f1 -d' '\"").remove(" ").split("\n");
     } else {
-        list << cmd->getOutput("su $(logname) -c \"flatpak -d list " + user + type + "|cut -f8\"").remove(" ").split("\n");
+        list << cmd->getOutput("su -l $(logname) -c \"flatpak -d list " + user + type + "|cut -f8\"").remove(" ").split("\n");
     }
     if (list == QStringList("")) list == QStringList();
     return list;
@@ -1773,7 +1773,7 @@ void MainWindow::on_buttonInstall_clicked()
     } else if (tree == ui->treeFlatpak) {
         setConnections();
         setCursor(QCursor(Qt::BusyCursor));
-        if (cmd->run("su $(logname) -c \"socat SYSTEM:'flatpak install -y " + user + ui->comboRemote->currentText() + " " + change_list.join(" ") + "',stderr STDIO\"") == 0) {
+        if (cmd->run("su -l $(logname) -c \"socat SYSTEM:'flatpak install -y " + user + ui->comboRemote->currentText() + " " + change_list.join(" ") + "',stderr STDIO\"") == 0) {
             displayFlatpaks(true);
             indexFilterFP.clear();
             ui->comboFilterFlatpak->setCurrentIndex(0);
@@ -1940,7 +1940,7 @@ void MainWindow::on_buttonUninstall_clicked()
         setCursor(QCursor(Qt::BusyCursor));
         for (const QString &app : change_list) {
             setConnections();
-            if (cmd->run("su $(logname) -c \"socat SYSTEM:'flatpak uninstall " + conf + user + app + "',stderr STDIO\"") != 0) { // success if all processed successfuly, failure if one failed
+            if (cmd->run("su -l $(logname) -c \"socat SYSTEM:'flatpak uninstall " + conf + user + app + "',stderr STDIO\"") != 0) { // success if all processed successfuly, failure if one failed
                 success = false;
             }
         }
@@ -2095,7 +2095,7 @@ void MainWindow::on_tabWidget_currentChanged(int index)
                     item->setText(5, "installed");
                 }
             }
-            cmd->run("su $(logname) -c \"flatpak remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo\"");
+            cmd->run("su -l $(logname) -c \"flatpak remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo\"");
             if (cmd->getExitCode(true) != 0) {
                 QMessageBox::critical(this, tr("Flathub remote failed"), tr("Flathub remote could not be added"));
                 ui->tabWidget->setCurrentIndex(0);
@@ -2113,7 +2113,7 @@ void MainWindow::on_tabWidget_currentChanged(int index)
             break;
         }
         setCursor(QCursor(Qt::BusyCursor));
-        cmd->run("su $(logname) -c \"flatpak remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo\"");
+        cmd->run("su -l $(logname) -c \"flatpak remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo\"");
         if (cmd->getExitCode(true) != 0) {
             QMessageBox::critical(this, tr("Flathub remote failed"), tr("Flathub remote could not be added"));
             ui->tabWidget->setCurrentIndex(0);
@@ -2444,7 +2444,7 @@ void MainWindow::on_buttonUpgradeFP_clicked()
     setConnections();
     setCursor(QCursor(Qt::BusyCursor));
 
-    if(cmd->run("su $(logname) -c \"socat SYSTEM:'flatpak update " + user.trimmed() + "',stderr STDIO\"") == 0) {
+    if(cmd->run("su -l $(logname) -c \"socat SYSTEM:'flatpak update " + user.trimmed() + "',stderr STDIO\"") == 0) {
         displayFlatpaks(true);
         setCursor(QCursor(Qt::ArrowCursor));
         QMessageBox::information(this, tr("Done"), tr("Processing finished successfully."));
@@ -2470,7 +2470,7 @@ void MainWindow::on_buttonRemotes_clicked()
         showOutput();
         setConnections();
         setCursor(QCursor(Qt::BusyCursor));
-        if (cmd->run("su $(logname) -c \"socat SYSTEM:'flatpak install -y " + dialog->getUser() + "--from " + dialog->getInstallRef().replace(":", "\\:") + "',stderr STDIO\"") == 0) {
+        if (cmd->run("su -l $(logname) -c \"socat SYSTEM:'flatpak install -y " + dialog->getUser() + "--from " + dialog->getInstallRef().replace(":", "\\:") + "',stderr STDIO\"") == 0) {
             listFlatpakRemotes();
             displayFlatpaks(true);
             setCursor(QCursor(Qt::ArrowCursor));
@@ -2495,9 +2495,9 @@ void MainWindow::on_comboUser_activated(int index)
         user = "--user ";
         if (!updated) {
             setCursor(QCursor(Qt::BusyCursor));
-            cmd->run("su $(logname) -c \"flatpak --user remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo\"");
+            cmd->run("su -l $(logname) -c \"flatpak --user remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo\"");
             if (fp_ver >= VersionNumber("1.2.4")) {
-                cmd->run("su $(logname) -c \"flatpak update --appstream\"");
+                cmd->run("su -l $(logname) -c \"flatpak update --appstream\"");
             }
             setCursor(QCursor(Qt::ArrowCursor));
             updated = true;
